@@ -93,7 +93,9 @@ class GeoArray(object):
         if isinstance(path_or_array, str):
             assert ' ' not in path_or_array, "The given path contains whitespaces. This is not supported by GDAL."
 
-            if not os.path.exists(path_or_array) and not path_or_array.startswith('/vsi'):
+            if not os.path.exists(path_or_array) and \
+               not path_or_array.startswith('/vsi') and \
+               not path_or_array.startswith('HDF'):
                 raise FileNotFoundError(path_or_array)
 
         if isinstance(path_or_array, GeoArray) or issubclass(getattr(path_or_array, '__class__'), GeoArray):
@@ -154,8 +156,11 @@ class GeoArray(object):
             return
 
         if not dt_min <= _nodata <= dt_max:
-            raise ValueError("The given no-data value (%s) is out range for data type %s."
-                             % (self._initParams['nodata'], str(np.dtype(self.dtype))))
+            if np.issubdtype(self.dtype, np.floating) and np.isnan(_nodata):
+                pass
+            else:
+                raise ValueError("The given no-data value (%s) is out range for data type %s."
+                                 % (self._initParams['nodata'], str(np.dtype(self.dtype))))
 
     @property
     def arr(self):
@@ -1148,7 +1153,7 @@ class GeoArray(object):
                              nodataVal=None, out_prj=None, ignore_rotation=False):
         # handle limits
         if boundsMap:
-            boundsMapPrj = boundsMapPrj if boundsMapPrj else self.prj
+            boundsMapPrj = boundsMapPrj or self.prj
             image2plot, gt, prj = self.get_mapPos(boundsMap, boundsMapPrj, band2get=band,
                                                   fillVal=nodataVal if nodataVal is not None else self.nodata)
         else:
@@ -1362,22 +1367,30 @@ class GeoArray(object):
         # get image to plot
         # (reproject to LonLat as workaround in case self.epsg is None because cartopy relies on an existing EPSG code)
         nodataVal = nodataVal if nodataVal is not None else self.nodata
-        gA2plot = GeoArray(*self._get_plottable_image(xlim, ylim, band, boundsMap=boundsMap,
-                                                      boundsMapPrj=boundsMapPrj, res_factor=res_factor,
+        gA2plot = GeoArray(*self._get_plottable_image(xlim, ylim, band,
+                                                      boundsMap=boundsMap,
+                                                      boundsMapPrj=boundsMapPrj,
+                                                      res_factor=res_factor,
                                                       nodataVal=nodataVal,
-                                                      out_prj=None if self.epsg is not None else 4326),
+                                                      # FIXME EPSG:4326 fails for extraterrestrial data
+                                                      out_prj=self.epsg or 4326
+                                                      ),
                            nodata=nodataVal)
         image2plot = gA2plot[:]
 
         # create map
         def get_cartopy_crs_from_epsg(epsg_code):
-            try:
-                return ccrs_from_epsg(epsg_code)
-            except ValueError:
-                if epsg_code == 4326:
-                    return PlateCarree()
-                else:
-                    raise NotImplementedError('The show_map() method currently does not support the given projection.')
+            if epsg_code:
+                try:
+                    return ccrs_from_epsg(epsg_code)
+                except ValueError:
+                    if epsg_code == 4326:
+                        return PlateCarree()
+                    else:
+                        raise NotImplementedError('The show_map() method currently does not support the given '
+                                                  'projection.')
+            else:
+                raise ValueError(f'Expected a valid EPSG code. Got {epsg_code}.')
 
         crs_in = get_cartopy_crs_from_epsg(gA2plot.epsg)
         crs_out = get_cartopy_crs_from_epsg(out_epsg if out_epsg is not None else gA2plot.epsg)
@@ -1578,14 +1591,14 @@ class GeoArray(object):
 
         :param poly: instance of shapely.geometry.Polygon
         """
-        self.arr, self.gt, self.projection = self.get_mapPos(mapBounds=poly.bounds, mapBounds_prj=self.prj)
+        self.arr, self.gt, self.projection = self.get_mapPos(mapBounds=poly.bounds)
         self.mask_nodata.arr, self.mask_nodata.gt, self.mask_nodata.projection = \
             self.mask_nodata.get_mapPos(mapBounds=poly.bounds, mapBounds_prj=self.prj)
         assert self.shape == self.mask_nodata.shape
 
         if self._mask_baddata is not None:
             self.mask_baddata.arr, self.mask_baddata.gt, self.mask_baddata.projection = \
-                self.mask_baddata.get_mapPos(mapBounds=poly.bounds, mapBounds_prj=self.prj)
+                self.mask_baddata.get_mapPos(mapBounds=poly.bounds)
             assert self.shape == self.mask_baddata.shape
 
         # update footprint polygon
@@ -1625,8 +1638,8 @@ class GeoArray(object):
 
         return GeneratorLen(out_gen, length=len(bounds_alltiles))
 
-    def get_mapPos(self, mapBounds, mapBounds_prj, band2get=None, out_prj=None, arr_gt=None, arr_prj=None, fillVal=None,
-                   rspAlg='near', progress=None, v=False):  # TODO implement slice for indexing bands
+    def get_mapPos(self, mapBounds, mapBounds_prj=None, band2get=None, out_prj=None, arr_gt=None, arr_prj=None,
+                   fillVal=None, rspAlg='near', progress=None, v=False):  # TODO implement slice for indexing bands
         # type: (tuple, str, int, str, tuple, str, int, str, bool, bool) -> (np.ndarray, tuple, str)
         """Return the array data of GeoArray at a given geographic position.
 
@@ -1646,6 +1659,7 @@ class GeoArray(object):
         :param v:               verbose mode (not related to GeoArray.v; must be explicitly set)
         :return:
         """
+        mapBounds_prj = mapBounds_prj if mapBounds_prj is not None else self.prj
         arr_gt = arr_gt or self.geotransform
         arr_prj = arr_prj or self.projection
         out_prj = out_prj or arr_prj
